@@ -33,8 +33,8 @@ struct Symbol {
 	    >
 	    data;
 
-	Label &label() { return std::get<Label>(data); }
-	Label const &label() const { return std::get<Label>(data); }
+	void linkToSection(Section &section);
+	void fixSectionOffset();
 };
 
 void sym_ForEach(void (*callback)(Symbol &));
@@ -44,6 +44,6 @@ void sym_AddSymbol(Symbol &symbol);
 // Finds a symbol in all the defined symbols.
 Symbol *sym_GetSymbol(std::string const &name);
 
-void sym_DumpLocalAliasedSymbols(std::string const &name);
+void sym_TraceLocalAliasedSymbols(std::string const &name);
 
 #endif // RGBDS_LINK_SYMBOL_HPP
