@@ -46,10 +46,11 @@
 
 	#include "link/lexer.hpp"
 	#include "link/layout.hpp"
+	#include "link/warning.hpp"
 
 	yy::parser::symbol_type yylex(); // Provided by layout.cpp
 
-#line 53 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 54 "/build/rgbds/src/rgbds/src/link/script.cpp"
 
 
 #ifndef YY_
@@ -122,7 +123,7 @@
 #define YYRECOVERING()  (!!yyerrstatus_)
 
 namespace yy {
-#line 126 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 127 "/build/rgbds/src/rgbds/src/link/script.cpp"
 
   /// Build a parser object.
   parser::parser ()
@@ -592,128 +593,128 @@ namespace yy {
           switch (yyn)
             {
   case 4: // line: "INCLUDE" string "end of line"
-#line 53 "link/script.y"
+#line 54 "link/script.y"
                                {
 		lexer_IncludeFile(std::move(yystack_[1].value.as < std::string > ())); // Note: this additionally increments the line number!
 	}
-#line 600 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 601 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 5: // line: directive "end of line"
-#line 56 "link/script.y"
+#line 57 "link/script.y"
                             {
 		lexer_IncLineNo();
 	}
-#line 608 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 609 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 6: // line: "end of line"
-#line 59 "link/script.y"
+#line 60 "link/script.y"
                   {
 		lexer_IncLineNo();
 	}
-#line 616 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 617 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 7: // line: error "end of line"
-#line 63 "link/script.y"
+#line 64 "link/script.y"
                         {
 		yyerrok;
 		lexer_IncLineNo();
 	}
-#line 625 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 626 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 8: // directive: sect_type
-#line 70 "link/script.y"
+#line 71 "link/script.y"
                   {
 		layout_SetSectionType(yystack_[0].value.as < SectionType > ());
 	}
-#line 633 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 634 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 9: // directive: sect_type number
-#line 73 "link/script.y"
+#line 74 "link/script.y"
                            {
 		layout_SetSectionType(yystack_[1].value.as < SectionType > (), yystack_[0].value.as < uint32_t > ());
 	}
-#line 641 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 642 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 10: // directive: sect_type "FLOATING"
-#line 76 "link/script.y"
+#line 77 "link/script.y"
                              {
 		layout_SetFloatingSectionType(yystack_[1].value.as < SectionType > ());
 	}
-#line 649 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 650 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 11: // directive: "FLOATING"
-#line 79 "link/script.y"
+#line 80 "link/script.y"
                    {
 		layout_MakeAddrFloating();
 	}
-#line 657 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 658 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 12: // directive: "ORG" number
-#line 82 "link/script.y"
+#line 83 "link/script.y"
                      {
 		layout_SetAddr(yystack_[0].value.as < uint32_t > ());
 	}
-#line 665 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 666 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 13: // directive: "ALIGN" number
-#line 85 "link/script.y"
+#line 86 "link/script.y"
                        {
 		layout_AlignTo(yystack_[0].value.as < uint32_t > (), 0);
 	}
-#line 673 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 674 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 14: // directive: "ALIGN" number "," number
-#line 88 "link/script.y"
+#line 89 "link/script.y"
                                     {
 		layout_AlignTo(yystack_[2].value.as < uint32_t > (), yystack_[0].value.as < uint32_t > ());
 	}
-#line 681 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 682 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 15: // directive: "DS" number
-#line 91 "link/script.y"
+#line 92 "link/script.y"
                     {
 		layout_Pad(yystack_[0].value.as < uint32_t > ());
 	}
-#line 689 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 690 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 16: // directive: string optional
-#line 94 "link/script.y"
+#line 95 "link/script.y"
                           {
 		layout_PlaceSection(yystack_[1].value.as < std::string > (), yystack_[0].value.as < bool > ());
 	}
-#line 697 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 698 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 17: // optional: %empty
-#line 100 "link/script.y"
+#line 101 "link/script.y"
                {
 		yylhs.value.as < bool > () = false;
 	}
-#line 705 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 706 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
   case 18: // optional: "OPTIONAL"
-#line 103 "link/script.y"
+#line 104 "link/script.y"
                    {
 		yylhs.value.as < bool > () = true;
 	}
-#line 713 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 714 "/build/rgbds/src/rgbds/src/link/script.cpp"
     break;
 
 
-#line 717 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 718 "/build/rgbds/src/rgbds/src/link/script.cpp"
 
             default:
               break;
@@ -1241,8 +1242,8 @@ namespace yy {
   const signed char
   parser::yyrline_[] =
   {
-       0,    48,    48,    49,    53,    56,    59,    63,    70,    73,
-      76,    79,    82,    85,    88,    91,    94,   100,   103
+       0,    49,    49,    50,    54,    57,    60,    64,    71,    74,
+      77,    80,    83,    86,    89,    92,    95,   101,   104
   };
 
   void
@@ -1274,13 +1275,13 @@ namespace yy {
 
 
 } // yy
-#line 1278 "/build/rgbds/src/rgbds/src/link/script.cpp"
+#line 1279 "/build/rgbds/src/rgbds/src/link/script.cpp"
 
-#line 108 "link/script.y"
+#line 109 "link/script.y"
 
 
 /******************** Error handler ********************/
 
 void yy::parser::error(std::string const &msg) {
-	lexer_Error("%s", msg.c_str());
+	scriptError("%s", msg.c_str());
 }
